/********************************************************************************************
 * FILE            : dz1611_config.c
 * AUTHOR:         : Emil Jovanov
 * DESCRIPTION     : Application specifric board configuration.
 *
 * REVISION HISTORY :
 * 20070128    : Sparkfun DZ1611_board
 ********************************************************************************************/
/********************************************************************************************
 * #includes
 ********************************************************************************************/
//#include <string.h>
#include "msp430x16x.h"
#include "dz1611_config.h"

/********************************************************************************************
 * ROUTINE:     TimerAInitialize
 * AUTHOR:
 * DATE:        11.06.04
 * ARGUMENTS:   void
 * RETURN:      void
 *
 * DESCRIPTION: Delay ~10ms
 ********************************************************************************************/
void TimerAInitialize(void)
{
//  TACTL = TACLR + TASSEL_1 + ID_2; // clear and select ACLK, don't start
  TACTL = TACLR + TASSEL_1; // clear and select ACLK, don't start
        // timer clock is 32KHz/8/4=1KHz
  
  TACCR0 = TIMER_A_CONST;     // generate interrupt every 1000ms 
  TACCTL0 = CCIE;             // CCR0 interrupt enabled, reset flags
  TACTL |= MC_1;       	// start timer in UP mode (count up to CCR0)
}

/********************************************************************************************
 * ROUTINE:     BoardInitialize
 * AUTHOR:
 * DATE:        1/28/07
 * ARGUMENTS:   void
 * RETURN:      void
 *
 * DESCRIPTION: Board / Application level Initialization
 ********************************************************************************************/
void Board_Initialize(void) {

  WDTCTL = WDTPW + WDTHOLD;             // Stop watchdog timer

  LED_SETUP();    // prepare outputs for LEDs
  
  // SpeedUpClock
  IFG2 = 0; IFG1 = 0;

  // XTAL1 high frequency, no XTAL2
//  BCSCTL1 = DIVA_3 + RSEL2;  // Enable XT2, XT1 is low-frequency, div /8
  BCSCTL1 = RSEL2;  // Enable XT2, XT1 is low-frequency, div /8

  /*wait in loop until crystal stabilizes*/
  do
  {
    IFG1 &= ~OFIFG;
  }
  while (OFIFG & IFG1);
  IFG1 &= ~OFIFG;   /*Reset osc. fault flag again */

  // Blink once to indicate that everything is OK now
  LEDON1;
  SW_delay();
  LEDOFF1;
  
  // Set fast MCLK - XT2CLK and SMCLK = DCOCLK 
  BCSCTL2=SELM_2+SELS;  
  
}

/********************************************************************************************
 * ROUTINE:     UART_Initialize
 * AUTHOR:
 * DATE:        11.06.04
 * ARGUMENTS:   void
 * RETURN:      void
 *
 * DESCRIPTION: Initialize the UART
 ********************************************************************************************/
void UART_Initialize(void) {

#ifdef USE_UART0
  // Keep UART in RESET state during configuration
  U0CTL |= SWRST;
  P3SEL |= BIT4+BIT5;		// P3.4,5 = USART0 TXD/RXD
  ME1 |= UTXE0 + URXE0;		// Enable USART0 TXD/RXD
  UCTL0 |= CHAR;			// 8-bit character
  UTCTL0 |= SSEL1;			// UCLK = SMCLK (6MHz)
  
//  UBR00=0xD0; UBR10=0x00; UMCTL0=0x11; /* uart0 8000000Hz 38406bps */
  UBR00=0x9C; UBR10=0x00; UMCTL0=0x44; /* uart0 6000000Hz 38412bps */

  // Clear RESET state
  UCTL0 &= ~SWRST;                          // Initialize USART state machine
  U0RCTL = 0;

#ifdef UART0_INT_DRIVEN
  uart0_rx_head = 0;
  uart0_rx_tail = 0;
  uart0_tx_head = 0;
  uart0_tx_tail = 0;
  uart0_flags = 0;

  IE1 |= UTXIE0 + URXIE0;  // enable TX and RX interrupts
#endif // UART0_INT_DRIVEN
#endif // USE_UART0

/*** UART1 Initialization */
#ifdef USE_UART1

   // Keep UART in RESET state during configuration
  U1CTL |= SWRST;
  P3SEL |= BIT6+BIT7;		// bits 6-7 are for special function UART1
  ME2 |= URXE1 + UTXE1; // UART module enable
  UCTL1 = CHAR;
  UTCTL1 |= SSEL1; // Use ACLK
  URCTL1 = 0;

  // Clear RESET state
  U1CTL &= ~SWRST;

#ifdef UART1_INT_DRIVEN
  uart1_rx_head = 0;
  uart1_rx_tail = 0;
  uart1_tx_head = 0;
  uart1_tx_tail = 0;
  uart1_flags = 0;
  IE2 |= UTXIE1 + URXIE1;  // enable TX and RX interrupts
#endif // UART1_INT_DRIVEN
#endif // USE_UART1

} // end UART_Initialize

/********************************************************************************************
 * ROUTINE:     SW_delay
 * AUTHOR:
 * DATE:        1/20/07
 * ARGUMENTS:   void
 * RETURN:      void
 *
 * DESCRIPTION: Short software delay, 10000 loop interations
 ********************************************************************************************/
void SW_delay(void) {

    volatile unsigned int i;            // volatile to prevent optimization

    i = 10000;                          // SW Delay
    do i--;
    while (i != 0);
}
