/********************************************************************************************
 * FILE            : dz1611_config.h
 * AUTHOR:         : Emil Jovanov
 * DESCRIPTION     : Board configuration

 * REVISION HISTORY :
 * 02.10.04  E.J.   : First version
********************************************************************************************/
#ifndef _DZ1611_CONFIG_H_
#define _DZ1611_CONFIG_H_

//***** USART Configuration *****
#define USE_UART0  // uncomment this to compile in functions for UART0
// #define USE_UART1  // uncomment this to compile in functions for UART1

/* uncomment this to make UART interrupt driven */
#define UART0_INT_DRIVEN
// #define UART1_INT_DRIVEN

//*** RTS/CTS control
// #define UART0_USING_CTS_RTS
// #define UART1_USING_CTS_RTS

//***** UART0 *****
#ifdef UART0_INT_DRIVEN
#ifdef USE_UART0
	#define UART0_RX_BUFSIZE  64
	#define UART0_TX_BUFSIZE  64
	extern char uart0_rx_buf[UART0_RX_BUFSIZE];
	extern char uart0_tx_buf[UART0_TX_BUFSIZE];
	extern unsigned char uart0_rx_head, uart0_rx_tail;
	extern unsigned char uart0_tx_head, uart0_tx_tail;
	extern unsigned char uart0_flags;
#endif // USE_UART0
#endif // UART0_INT_DRIVEN

//***** UART0 *****
#ifdef UART1_INT_DRIVEN
#ifdef USE_UART1
	#define UART1_RX_BUFSIZE  128
	#define UART1_TX_BUFSIZE  128
	extern char uart1_rx_buf[UART1_RX_BUFSIZE];
	extern char uart1_tx_buf[UART1_TX_BUFSIZE];
	extern uint8 uart1_rx_head, uart1_rx_tail;
	extern uint8 uart1_tx_head, uart1_tx_tail;
	extern uint8 uart1_flags;
#endif //USE_UART1
#endif // UART1_INT_DRIVEN

#include "serial.h"

#define true 1;
#define false 0;

/*** Timer CCR0 constants ***/
#define TIMER_A_CONST 32768        // 1s with XTAL1=32768Hz

/*** LEDs ***/
#define LED_SETUP()	P1DIR |= BIT0+BIT1+BIT2+BIT3;P1OUT=0;

#define LEDON1     P1OUT |= BIT0
#define LEDOFF1    P1OUT &= ~BIT0
#define LEDTOGGLE1    P1OUT ^= BIT0

#define LEDON2     P1OUT |= BIT1
#define LEDOFF2    P1OUT &= ~BIT1
#define LEDTOGGLE2    P1OUT ^= BIT1

#define LEDON3     P1OUT |= BIT2
#define LEDOFF3    P1OUT &= ~BIT2
#define LEDTOGGLE3    P1OUT ^= BIT2

#define LEDON4     P1OUT |= BIT3
#define LEDOFF4    P1OUT &= ~BIT3
#define LEDTOGGLE4    P1OUT ^= BIT3

/*** Variables ***/
extern unsigned int num_samp;  // sample counter, interval timer
#define DSCOPE_PACKET_SIZE 4
extern unsigned char dscope_packet[DSCOPE_PACKET_SIZE];  // sample counter, interval timer
extern unsigned int cs;        // checksum

// ***** Function declarations ***** /
void delay(void);
void short_delay(void);
void Board_Initialize(void);
void TimerAInitialize(void);
void UART_Initialize(void);
void delay10ms(void);
void SW_delay(void);
  
////////////////////////////////////////////////////////////////
//   Map UART  Functions
////////////////////////////////////////////////////////////////
#ifdef USE_UART0
  #define UART_putchar        UART0_putchar
  #define UART_ClearRxBuffer  UART0_ClearRxBuffer
  #define UART_ClearTxBuffer  UART0_ClearTxBuffer
  #define UART_RXready        UART0_RXready
#elif defined(USE_UART1)
  #define UART_putchar        UART1_putchar
  #define UART_ClearRxBuffer  UART1_ClearRxBuffer
  #define UART_ClearTxBuffer  UART1_ClearTxBuffer
  #define UART_RXready        UART1_RXready
#endif

#endif //_DZ1611_CONFIG_H_
