//******************************************************************************
//  DZ1611 Board Demo - Timer example, ISR use
//
//  file: timer_example.c
//
//  Description: TimerA generates regular interrupts. Use USART0, UART 38400,
//    6MHz XTAL2, Echo a received character in RX ISR. 
//
//  E. Jovanov. 
//  UAH
//  January 2007
//******************************************************************************

#include  <msp430x16x.h>
#include "dz1611_config.h"
#include "serial.h"

void main(void)
{

  Board_Initialize();     // initialize peripherals
  TimerAInitialize();     // regular timer interrupts
  UART_Initialize();
  
  _EINT();
  
  // Mainloop
  for (;;)    // infinite loop
  {
    //>>>>>> un-comment for low power operation
    _BIS_SR(LPM0_bits + GIE);    // Enter LPMode w/interrupt
    // Do you have to make some additional processing here?
  }
}

/****************************/
#pragma vector=TIMERA0_VECTOR
__interrupt void timer_isr(void)
{
  //>>>>>> un-comment for low power operation
  //_BIC_SR_IRQ(LPM0_bits);              // Clear LPM bits from 0(SR)
  TACCTL0 = CCIE;             // CCR0 interrupt enabled, reset flags

  LEDTOGGLE1;                          // Indication
  //TACCR0 += TIMER_A_CONST;             // Add Offset to CCR0

}

/****************************/
#pragma vector=UART0RX_VECTOR
__interrupt void usart0_rx (void)
{
  //>>>>>> un-comment for low power operation
  //_BIC_SR_IRQ(LPM0_bits);                   // Clear LPM3 bits from 0(SR)
  TXBUF0 = RXBUF0;                          // RXBUF0 to TXBUF0
  LEDTOGGLE2;
}

/****************************/
#pragma vector=UART0TX_VECTOR
__interrupt void usart0_tx (void)
{
  LEDTOGGLE3;
}
