//******************************************************************************
//  DZ1611 Board Demo - Timer example, ISR use
//
//  file: timer_example2.c
//
//  Description: TimerA generates regular interrupts. 
//    Use USART0, UART 38400. 6MHz XTAL2. 
//    Wait for a complete line received on UARTO and process commands. 
//
//  E. Jovanov. 
//  UAH
//  January 2007
//******************************************************************************

#include  <msp430x16x.h>
#include "dz1611_config.h"
#include "serial.h"

/***** variables *****/
unsigned char new_message_flag;
unsigned char time_schedule_flag;
char OK_MSG[]={'O','K',0xD,0xA,'\0'};
//char OK_MSG[]="OK";
char msg[20];

/***** functions *****/
void process_message(void);
void schedule_new_event(void);

//*** Beginning of main
void main(void)
{
	char i,c;
	
	//*** initialize variables
	new_message_flag = false;
	time_schedule_flag = false;

	//*** board initialization
	Board_Initialize();     // initialize peripherals
	TimerAInitialize();     // regular timer interrupts
	UART_Initialize();

	_EINT();

	//*** Mainloop
	for (;;)    // infinite loop
	{
		_BIS_SR(LPM0_bits + GIE);    // Go back to LPMode w/interrupt
		// Do you have to make some additional processing here?
		LEDTOGGLE3;
		if (uart0_flags & UART_CR_RECEIVED)
		{
			// one line of text has been received, initiate processing
			UART0_putstring(OK_MSG);
			c=0;i=0;
			while (~UART0_RxBufferEmpty() && c!=CR)
			{
				c=UART0_getchar();
				msg[i++]=c;
//				UART0_putchar(UART0_getchar());
			}
			msg[i]=0;
			UART0_putstring(msg);UART0_putchar(CR);UART0_putchar(LF);
			uart0_flags &= ~ UART_CR_RECEIVED; // reset flag
		}
	} // end infinite loop
	
} // end_main

/****************************/
#pragma vector=TIMERA0_VECTOR
__interrupt void Timer_ISR(void)
{
  //>>>>>> un-comment for low power operation
  //_BIC_SR_IRQ(LPM0_bits);              // Clear LPM bits from 0(SR)
  TACCTL0 = CCIE;             // CCR0 interrupt enabled, reset flags

  LEDTOGGLE1;                          // Indication
  //TACCR0 += TIMER_A_CONST;             // Add Offset to CCR0

}
